EasyExtend.langlets.p4d.bytelet.ByteletSchema

Package EasyExtend :: Package langlets :: Package p4d :: Module bytelet :: Class ByteletSchema |
[hide private]
[frames] | no frames]

# Class ByteletSchema

     object --+
              |
    p4dbase.P4D --+
                  |
            Bytelet --+
                      |
                     ByteletSchema

Nested Classes | [hide private]
| ListType Class used to represent lists of P4D objects.

Instance Methods | [hide private]
__repr__(self) repr(x) |
update(self, back_propagate=True) |
parse(self, hexcode, strict=True) Parses hexcode into Bytelet according to a Schema. |
_parse_std_schema(self, hexcode, strict) |
_split(self, hexcode) |
_scan_with_tlvlist(self, hexcode, tagset) |
_parse_tlvlist_schema(self, hexcode, strict) |
Inherited from `Bytelet`: `__delitem__`, `__init__`, `__len__`, `__setattr__`, `clone`, `content`, `flow_obj_init`, `hex`, `text` Inherited from `Bytelet` (private): `_check_size`, `_lazy_child_access` Inherited from `p4dbase.P4D`: `CDATA`, `__getattr__`, `__iter__`, `__nonzero__`, `attribute`, `attributes`, `child`, `children`, `comment`, `first_child`, `get`, `namespace`, `next`, `object_data`, `p4dstr`, `search`, `xmlstr` Inherited from `p4dbase.P4D` (private): `_attr_access`, `_create_attributes`, `_extract_from_qname`, `_remap` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__str__`

Class Methods | [hide private]
Inherited from `Bytelet`: `from_p4dnode` Inherited from `p4dbase.P4D`: `eval`, `from_html`, `from_xml`

Class Variables | [hide private]
Inherited from `p4dbase.P4D`: `p4d_kwd`, `parser`

Properties | [hide private]
Inherited from `Bytelet`: `tag` Inherited from `Bytelet` (private): `_attrs`, `_children`, `_content`, `_idx`, `_initialized`, `_name`, `_parent`, `_tree` Inherited from `object`: `__class__`

Method Details | [hide private]

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

### update(self, back_propagate=True) |
Overrides: p4dbase.P4D.update

### parse(self, hexcode, strict=True) |
Parses hexcode into Bytelet according to a Schema. Parameters: `hexcode` - any object that can be converted into a Hex object.